summaryrefslogtreecommitdiffstats
path: root/tqdbusproxy.h
diff options
context:
space:
mode:
Diffstat (limited to 'tqdbusproxy.h')
-rw-r--r--tqdbusproxy.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/tqdbusproxy.h b/tqdbusproxy.h
index ae31f40..7cf2e52 100644
--- a/tqdbusproxy.h
+++ b/tqdbusproxy.h
@@ -245,10 +245,10 @@ public:
* This basic constructor allows to create a proxy and specify the peer
* object and interface later on.
*
* @param tqparent TQObject tqparent
* @param name TQObject name
*/
- TQT_DBusProxy(TQObject* tqparent = 0, const char* name = 0);
+ TQT_DBusProxy(TQObject* parent = 0, const char* name = 0);
/**
* @brief Creates a proxy on a given connection without binding it to a
@@ -262,10 +262,10 @@ public:
* filtering for a specific peer.
*
* @param connection the D-Bus connection to work on
* @param tqparent TQObject tqparent
* @param name TQObject name
*/
- TQT_DBusProxy(const TQT_DBusConnection& connection, TQObject* tqparent = 0,
+ TQT_DBusProxy(const TQT_DBusConnection& connection, TQObject* parent = 0,
const char* name = 0);
/**
@@ -279,12 +279,12 @@ public:
* @param path the peer object's path within its host application
* @param interface the interface to work with
* @param connection the D-Bus connection to work on
* @param tqparent TQObject tqparent
* @param name TQObject name
*/
TQT_DBusProxy(const TQString& service, const TQString& path,
const TQString& interface, const TQT_DBusConnection& connection,
- TQObject* tqparent = 0, const char* name = 0);
+ TQObject* parent = 0, const char* name = 0);
/**
* @brief Destroys the proxy instance
@@ -245,10 +245,10 @@ public:
* object and interface later on.
*
- * @param tqparent TQObject tqparent
+ * @param parent TQObject parent
* @param name TQObject name
*/
@@ -262,10 +262,10 @@ public:
*
* @param connection the D-Bus connection to work on
- * @param tqparent TQObject tqparent
+ * @param parent TQObject parent
* @param name TQObject name
*/
@@ -279,12 +279,12 @@ public:
* @param interface the interface to work with
* @param connection the D-Bus connection to work on
- * @param tqparent TQObject tqparent
+ * @param parent TQObject parent
* @param name TQObject name
*/